<?php

/**
 * Provide the view for the metabox parameters: leadbox-options
 *
 * @since 		1.0
 * @package 	Leadferno
 * @subpackage 	Leadferno/admin/partials
 */

wp_nonce_field($this->plugin_name, 'leadbox_options');

$post_id = get_the_ID();

?><div id="leadferno-admin-metabox-options" class="inside">
	<table class="form-table">
		<tbody><?php
			// Help guide
			?><tr id="leadferno-admin-metabox-help">
				<th><label for="leadbox-help"><?php esc_html_e('Help guide:', 'leadferno'); ?></label></th>
				<td>
					<a href="https://help.leadferno.com/help" target="_blank"><?php
						esc_html_e('Get help', 'leadferno'); ?>
					</a>
				</td>
			</tr><?php

			// Enable
			$atts = array();
			$atts['description'] = '';
			$atts['id'] = 'leadbox-enable';
			$atts['label'] = 'Enable';
			$atts['name'] = 'leadbox-enable';
			$atts['type'] = 'radio';
			$atts['value'] = 'yes';
			$atts['selections'] = array(
				array(
					'value' => 'yes',
					'label' => 'Yes'
				),
				array(
					'value' => 'no',
					'label' => 'No'
				)
			);

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-enable"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/radio.php');
			?></tr><?php

			// BID
			$atts = array();
			$atts['description'] = 'Get from Leadbox in your Leadferno account.';
			$atts['id'] = 'leadbox-bid';
			$atts['label'] = 'DATA-BID';
			$atts['name'] = 'leadbox-bid';
			$atts['placeholder'] = '';
			$atts['type'] = 'text';
			$atts['value'] = '';

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-bid"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/text.php');
			?></tr><?php

			// Type
			$atts = array();
			$atts['description'] = '';
			$atts['id'] = 'leadbox-type';
			$atts['label'] = 'Type';
			$atts['name'] = 'leadbox-type';
			$atts['type'] = 'radio';
			$atts['value'] = 'single';
			$atts['selections'] = array(
				array(
					'value' => 'single',
					'label' => 'Single Profile'
				),
				array(
					'value' => 'multi',
					'label' => 'Multi-Profile'
				)
			);

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-type"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/radio.php');
			?></tr><?php

			// Display
			$atts = array();
			$atts['description'] = 'Choose where your Leadbox will appear on your website.';
			$atts['id'] = 'leadbox-display';
			$atts['label'] = 'Display';
			$atts['name'] = 'leadbox-display';
			$atts['type'] = 'select';
			$atts['value'] = '1';
			$atts['selections'] = array(
				array(
					'value' => '1',
					'label' => 'On all pages'
				),
				array(
					'value' => '2',
					'label' => 'Only on the pages selected'
				),
				array(
					'value' => '-2',
					'label' => 'On all pages except those selected'
				)
			);

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-display"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/select.php');
			?></tr><?php

			// Pages
			$args = array(
				'child_of'     => 0,
				'sort_order'   => 'ASC',
				'sort_column'  => 'post_title',
				'hierarchical' => 1,
				'parent'       => -1,
				'number'       => 0,
				'offset'       => 0,
				'post_type'    => 'page',
				'post_status'  => 'publish'
			);

			$pages = get_pages($args);

			$atts = array();
			$atts['description'] = '';
			$atts['id'] = 'leadbox-pages';
			$atts['label'] = 'Page Selection';
			$atts['name'] = 'leadbox-pages[]'; // [] for array
			$atts['type'] = 'checkbox';
			$atts['value'] = array();
			$atts['selections'] = array();

			if (!empty($pages))
			{
				foreach ($pages as $page)
				{
					if ($page->post_parent)
					{
						$parent_level = $atts['selections'][$page->post_parent]['level'];
						$level = $parent_level + 1;
					}
					else
						$level = 0;

					$atts['selections'][$page->ID] = array(
						'value' => $page->ID,
						'label' => $page->post_title,
						'level' => $level
					);
				}
			}

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-pages" class="hidden"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/page-checkbox.php');
			?></tr><?php

			// Posts
			$args = array(
				'post_type' => 'post',
				'post_status' => 'publish',
				'posts_per_page' => -1,
				'order' => 'ASC',
				'orderby' => 'post_title',
			);

			$posts = get_posts($args);

			$atts = array();
			$atts['description'] = '';
			$atts['id'] = 'leadbox-posts';
			$atts['label'] = 'Post Selection';
			$atts['name'] = 'leadbox-posts[]'; // [] for array
			$atts['type'] = 'checkbox';
			$atts['value'] = array();
			$atts['selections'] = array();

			if (!empty($posts))
			{
				foreach ($posts as $post)
				{
					if ($post->post_parent)
					{
						$parent_level = $atts['selections'][$post->post_parent]['level'];
						$level = $parent_level + 1;
					}
					else
						$level = 0;

					$atts['selections'][$post->ID] = array(
						'value' => $post->ID,
						'label' => $post->post_title,
						'level' => $level
					);
				}
			}

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-posts" class="hidden"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/post-checkbox.php');
			?></tr><?php

			// URLs
			$atts = array();
			$atts['description'] = '';
			$atts['id'] = 'leadbox-urls';
			$atts['label'] = 'Custom URLs';
			$atts['name'] = 'leadbox-urls[]'; // [] for array
			$atts['type'] = 'repeater';
			$atts['value'] = '';

			if (!empty(get_post_meta($post_id, $atts['id'], true)))
				$atts['value'] = get_post_meta($post_id, $atts['id'], true);

			apply_filters($this->plugin_name . '-field-' . $atts['id'], $atts);

			?><tr id="leadferno-admin-metabox-urls" class="hidden"><?php
				include(LEADFERNO__ADMIN_PLUGIN_DIR . 'partials/fields/repeater.php');
			?></tr>
		</tbody>
	</table>
</div>